summaryrefslogtreecommitdiffhomepage
path: root/libs/apprise/plugins/NotifyZulip.py
diff options
context:
space:
mode:
authormorpheus65535 <[email protected]>2021-12-01 21:19:18 -0500
committermorpheus65535 <[email protected]>2021-12-01 21:19:18 -0500
commitd51dc68ebb3910ca09bb40c33814d43b93d916b8 (patch)
tree569807abb70b41eb98dded56c17bd504e793da5b /libs/apprise/plugins/NotifyZulip.py
parent402c82d84f7bd51353348bea7d1a876ad9ecc5b1 (diff)
downloadbazarr-d51dc68ebb3910ca09bb40c33814d43b93d916b8.tar.gz
bazarr-d51dc68ebb3910ca09bb40c33814d43b93d916b8.zip
Updated Apprise notification module to the latest providers.v1.0.2-beta.2
Diffstat (limited to 'libs/apprise/plugins/NotifyZulip.py')
-rw-r--r--libs/apprise/plugins/NotifyZulip.py18
1 files changed, 9 insertions, 9 deletions
diff --git a/libs/apprise/plugins/NotifyZulip.py b/libs/apprise/plugins/NotifyZulip.py
index 2290efb0d..80ca94227 100644
--- a/libs/apprise/plugins/NotifyZulip.py
+++ b/libs/apprise/plugins/NotifyZulip.py
@@ -77,12 +77,12 @@ ZULIP_HTTP_ERROR_MAP = {
401: 'Unauthorized - Invalid Token.',
}
-# Used to break path apart into list of channels
+# Used to break path apart into list of streams
TARGET_LIST_DELIM = re.compile(r'[ \t\r\n,#\\/]+')
-# Used to detect a channel
+# Used to detect a streams
IS_VALID_TARGET_RE = re.compile(
- r'#?(?P<channel>[A-Z0-9_]{1,32})', re.I)
+ r'#?(?P<stream>[A-Z0-9_]{1,32})', re.I)
class NotifyZulip(NotifyBase):
@@ -142,8 +142,8 @@ class NotifyZulip(NotifyBase):
'type': 'string',
'map_to': 'targets',
},
- 'target_channel': {
- 'name': _('Target Channel'),
+ 'target_stream': {
+ 'name': _('Target Stream'),
'type': 'string',
'map_to': 'targets',
},
@@ -164,8 +164,8 @@ class NotifyZulip(NotifyBase):
# if one isn't defined in the apprise url
default_hostname = 'zulipchat.com'
- # The default channel to notify if no targets are specified
- default_notification_channel = 'general'
+ # The default stream to notify if no targets are specified
+ default_notification_stream = 'general'
def __init__(self, botname, organization, token, targets=None, **kwargs):
"""
@@ -218,8 +218,8 @@ class NotifyZulip(NotifyBase):
self.targets = parse_list(targets)
if len(self.targets) == 0:
- # No channels identified, use default
- self.targets.append(self.default_notification_channel)
+ # No streams identified, use default
+ self.targets.append(self.default_notification_stream)
def send(self, body, title='', notify_type=NotifyType.INFO, **kwargs):
"""